#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-chans
version:              3.0.0.11
visibility:           public
id:                   stm-chans-3.0.0.11-FvSGcL6ts223Fah2i3K6ah
key:                  stm-chans-3.0.0.11-FvSGcL6ts223Fah2i3K6ah
license:              BSD-3-Clause
copyright:            2011–2025 wren romano
maintainer:           wren@cpan.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             https://wrengr.org/software/hackage.html
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  b244a4cc3ebd97f4951d6330205b95e2
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-chans-3.0.0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-chans-3.0.0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-chans-3.0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-chans
hs-libraries:         HSstm-chans-3.0.0.11-FvSGcL6ts223Fah2i3K6ah
depends:              base-4.18.2.1 stm-2.5.1.0
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

